# Markov chain

## This is a mirror copy of Markov chain implementation (markovify) package by @jsvine

***

## https://github.com/jsvine/markovify

## Source code as of Dec 10, 2020 (c8eb4cf) + release package 0.8.3 as of Aug 2, 2020 (f1f615c).

## Coming soon: Stand-alone, single python module that will be tailored specifically for music.

***

### Project Los Angeles
### Tegridy Code 2021
